.. module:: eodag.utils

=====
Utils
=====

Logging
-------

.. automodule:: eodag.utils.logging
   :members:

Callbacks
-----------------

.. autofunction:: eodag.utils.DownloadedCallback
.. autofunction:: eodag.utils.ProgressCallback

Notebook
--------

.. automodule:: eodag.utils.notebook
   :members:
